/**
 * Data Connectivity Management API
 * Use the DCMS APIs to perform Metadata/Data operations.
 * OpenAPI spec version: 20210217
 * Contact: di_dcms_dev_ww_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { DataConnectivityManagementWaiter } from "./dataconnectivitymanagement-waiter";
export declare enum DataConnectivityManagementApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DataConnectivityManagementClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DataConnectivityManagementWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpOptions: any;
    targetService: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DataConnectivityManagementWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DataConnectivityManagementWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DataConnectivityManagementWaiter;
    /**
     * The Endpoint will be moved to the desired compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeEndpointCompartmentRequest
     * @return ChangeEndpointCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ChangeEndpointCompartment.ts.html |here} to see how to use ChangeEndpointCompartment API.
     */
    changeEndpointCompartment(changeEndpointCompartmentRequest: requests.ChangeEndpointCompartmentRequest): Promise<responses.ChangeEndpointCompartmentResponse>;
    /**
     * The registry will be moved to the desired compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeRegistryCompartmentRequest
     * @return ChangeRegistryCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ChangeRegistryCompartment.ts.html |here} to see how to use ChangeRegistryCompartment API.
     */
    changeRegistryCompartment(changeRegistryCompartmentRequest: requests.ChangeRegistryCompartmentRequest): Promise<responses.ChangeRegistryCompartmentResponse>;
    /**
     * Attaches list of DataAssets to the given endpoint
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateAttachDataAssetRequest
     * @return CreateAttachDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateAttachDataAsset.ts.html |here} to see how to use CreateAttachDataAsset API.
     */
    createAttachDataAsset(createAttachDataAssetRequest: requests.CreateAttachDataAssetRequest): Promise<responses.CreateAttachDataAssetResponse>;
    /**
     * Creates a connection under an existing data asset.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateConnectionRequest
     * @return CreateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateConnection.ts.html |here} to see how to use CreateConnection API.
     */
    createConnection(createConnectionRequest: requests.CreateConnectionRequest): Promise<responses.CreateConnectionResponse>;
    /**
     * Creates a connection validation.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateConnectionValidationRequest
     * @return CreateConnectionValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateConnectionValidation.ts.html |here} to see how to use CreateConnectionValidation API.
     */
    createConnectionValidation(createConnectionValidationRequest: requests.CreateConnectionValidationRequest): Promise<responses.CreateConnectionValidationResponse>;
    /**
     * This endpoint is used to trigger validation of dataAsset, connection, schema, entity, dataOperationConfig
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateConnectivityValidationRequest
     * @return CreateConnectivityValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateConnectivityValidation.ts.html |here} to see how to use CreateConnectivityValidation API.
     */
    createConnectivityValidation(createConnectivityValidationRequest: requests.CreateConnectivityValidationRequest): Promise<responses.CreateConnectivityValidationResponse>;
    /**
     * Creates a data asset with default connection.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDataAssetRequest
     * @return CreateDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateDataAsset.ts.html |here} to see how to use CreateDataAsset API.
     */
    createDataAsset(createDataAssetRequest: requests.CreateDataAssetRequest): Promise<responses.CreateDataAssetResponse>;
    /**
     * Provide data preview on live schema
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDataPreviewRequest
     * @return CreateDataPreviewResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateDataPreview.ts.html |here} to see how to use CreateDataPreview API.
     */
    createDataPreview(createDataPreviewRequest: requests.CreateDataPreviewRequest): Promise<responses.CreateDataPreviewResponse>;
    /**
     * Execute data profiling on live schema
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDataProfileRequest
     * @return CreateDataProfileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateDataProfile.ts.html |here} to see how to use CreateDataProfile API.
     */
    createDataProfile(createDataProfileRequest: requests.CreateDataProfileRequest): Promise<responses.CreateDataProfileResponse>;
    /**
     * DeRereferenced a dcms artifact.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDeReferenceArtifactRequest
     * @return CreateDeReferenceArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateDeReferenceArtifact.ts.html |here} to see how to use CreateDeReferenceArtifact API.
     */
    createDeReferenceArtifact(createDeReferenceArtifactRequest: requests.CreateDeReferenceArtifactRequest): Promise<responses.CreateDeReferenceArtifactResponse>;
    /**
     * Detaches list of DataAssets to the given endpoint
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDetachDataAssetRequest
     * @return CreateDetachDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateDetachDataAsset.ts.html |here} to see how to use CreateDetachDataAsset API.
     */
    createDetachDataAsset(createDetachDataAssetRequest: requests.CreateDetachDataAssetRequest): Promise<responses.CreateDetachDataAssetResponse>;
    /**
     * Creates a new Data Connectivity Management Endpoint ready for performing data Connectivity.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateEndpointRequest
     * @return CreateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateEndpoint.ts.html |here} to see how to use CreateEndpoint API.
     */
    createEndpoint(createEndpointRequest: requests.CreateEndpointRequest): Promise<responses.CreateEndpointResponse>;
    /**
     * Creates the data entity shape using the shape from the data asset.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateEntityShapeRequest
     * @return CreateEntityShapeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateEntityShape.ts.html |here} to see how to use CreateEntityShape API.
     */
    createEntityShape(createEntityShapeRequest: requests.CreateEntityShapeRequest): Promise<responses.CreateEntityShapeResponse>;
    /**
     * Call the operation to execute
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExecuteOperationJobRequest
     * @return CreateExecuteOperationJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateExecuteOperationJob.ts.html |here} to see how to use CreateExecuteOperationJob API.
     */
    createExecuteOperationJob(createExecuteOperationJobRequest: requests.CreateExecuteOperationJobRequest): Promise<responses.CreateExecuteOperationJobResponse>;
    /**
     * Creates a folder under a specefied registry.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateFolderRequest
     * @return CreateFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateFolder.ts.html |here} to see how to use CreateFolder API.
     */
    createFolder(createFolderRequest: requests.CreateFolderRequest): Promise<responses.CreateFolderResponse>;
    /**
     * This endpoint is used to create a connectivity task (like PushdownTask).
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateFullPushDownTaskRequest
     * @return CreateFullPushDownTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateFullPushDownTask.ts.html |here} to see how to use CreateFullPushDownTask API.
     */
    createFullPushDownTask(createFullPushDownTaskRequest: requests.CreateFullPushDownTaskRequest): Promise<responses.CreateFullPushDownTaskResponse>;
    /**
     * Reference a data asset.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateReferenceArtifactRequest
     * @return CreateReferenceArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateReferenceArtifact.ts.html |here} to see how to use CreateReferenceArtifact API.
     */
    createReferenceArtifact(createReferenceArtifactRequest: requests.CreateReferenceArtifactRequest): Promise<responses.CreateReferenceArtifactResponse>;
    /**
     * Creates a new Data Connectivity Management Registry ready for performing data Connectivity Management.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateRegistryRequest
     * @return CreateRegistryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateRegistry.ts.html |here} to see how to use CreateRegistry API.
     */
    createRegistry(createRegistryRequest: requests.CreateRegistryRequest): Promise<responses.CreateRegistryResponse>;
    /**
     * Execute network validation on selected data assets associated with the provided private endpoint
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateTestNetworkConnectivityRequest
     * @return CreateTestNetworkConnectivityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/CreateTestNetworkConnectivity.ts.html |here} to see how to use CreateTestNetworkConnectivity API.
     */
    createTestNetworkConnectivity(createTestNetworkConnectivityRequest: requests.CreateTestNetworkConnectivityRequest): Promise<responses.CreateTestNetworkConnectivityResponse>;
    /**
     * Removes a connection using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteConnectionRequest
     * @return DeleteConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/DeleteConnection.ts.html |here} to see how to use DeleteConnection API.
     */
    deleteConnection(deleteConnectionRequest: requests.DeleteConnectionRequest): Promise<responses.DeleteConnectionResponse>;
    /**
     * Deletes a connection validation.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteConnectionValidationRequest
     * @return DeleteConnectionValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/DeleteConnectionValidation.ts.html |here} to see how to use DeleteConnectionValidation API.
     */
    deleteConnectionValidation(deleteConnectionValidationRequest: requests.DeleteConnectionValidationRequest): Promise<responses.DeleteConnectionValidationResponse>;
    /**
     * Removes a data asset using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDataAssetRequest
     * @return DeleteDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/DeleteDataAsset.ts.html |here} to see how to use DeleteDataAsset API.
     */
    deleteDataAsset(deleteDataAssetRequest: requests.DeleteDataAssetRequest): Promise<responses.DeleteDataAssetResponse>;
    /**
     * Deletes a Data Connectivity Management Endpoint resource by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteEndpointRequest
     * @return DeleteEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/DeleteEndpoint.ts.html |here} to see how to use DeleteEndpoint API.
     */
    deleteEndpoint(deleteEndpointRequest: requests.DeleteEndpointRequest): Promise<responses.DeleteEndpointResponse>;
    /**
     * Removes a folder using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteFolderRequest
     * @return DeleteFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/DeleteFolder.ts.html |here} to see how to use DeleteFolder API.
     */
    deleteFolder(deleteFolderRequest: requests.DeleteFolderRequest): Promise<responses.DeleteFolderResponse>;
    /**
     * This api is used to delete a persisted NetworkValidationStatus by its key
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteNetworkConnectivityStatusRequest
     * @return DeleteNetworkConnectivityStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/DeleteNetworkConnectivityStatus.ts.html |here} to see how to use DeleteNetworkConnectivityStatus API.
     */
    deleteNetworkConnectivityStatus(deleteNetworkConnectivityStatusRequest: requests.DeleteNetworkConnectivityStatusRequest): Promise<responses.DeleteNetworkConnectivityStatusResponse>;
    /**
     * Deletes a Data Connectivity Management Registry resource by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteRegistryRequest
     * @return DeleteRegistryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/DeleteRegistry.ts.html |here} to see how to use DeleteRegistry API.
     */
    deleteRegistry(deleteRegistryRequest: requests.DeleteRegistryRequest): Promise<responses.DeleteRegistryResponse>;
    /**
     * Retrieves the connection details using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetConnectionRequest
     * @return GetConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetConnection.ts.html |here} to see how to use GetConnection API.
     */
    getConnection(getConnectionRequest: requests.GetConnectionRequest): Promise<responses.GetConnectionResponse>;
    /**
     * Retrieves a connection validation using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetConnectionValidationRequest
     * @return GetConnectionValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetConnectionValidation.ts.html |here} to see how to use GetConnectionValidation API.
     */
    getConnectionValidation(getConnectionValidationRequest: requests.GetConnectionValidationRequest): Promise<responses.GetConnectionValidationResponse>;
    /**
     * Retrieves details of a data asset using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDataAssetRequest
     * @return GetDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetDataAsset.ts.html |here} to see how to use GetDataAsset API.
     */
    getDataAsset(getDataAssetRequest: requests.GetDataAssetRequest): Promise<responses.GetDataAssetResponse>;
    /**
     * Retrieves the data entity details with the given name from live schema.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDataEntityRequest
     * @return GetDataEntityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetDataEntity.ts.html |here} to see how to use GetDataEntity API.
     */
    getDataEntity(getDataEntityRequest: requests.GetDataEntityRequest): Promise<responses.GetDataEntityResponse>;
    /**
     * Gets a Data Connectivity Management Endpoint by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetEndpointRequest
     * @return GetEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetEndpoint.ts.html |here} to see how to use GetEndpoint API.
     */
    getEndpoint(getEndpointRequest: requests.GetEndpointRequest): Promise<responses.GetEndpointResponse>;
    /**
     * Get the operation status or operation execution result
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExecuteOperationJobRequest
     * @return GetExecuteOperationJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetExecuteOperationJob.ts.html |here} to see how to use GetExecuteOperationJob API.
     */
    getExecuteOperationJob(getExecuteOperationJobRequest: requests.GetExecuteOperationJobRequest): Promise<responses.GetExecuteOperationJobResponse>;
    /**
     * Retrieves the folder details using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetFolderRequest
     * @return GetFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetFolder.ts.html |here} to see how to use GetFolder API.
     */
    getFolder(getFolderRequest: requests.GetFolderRequest): Promise<responses.GetFolderResponse>;
    /**
     * Get Status of network reachability check, with the timestamp when the status was last checked, for a given PrivateEndpoint-DataAsset pair
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetNetworkConnectivityStatusRequest
     * @return GetNetworkConnectivityStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetNetworkConnectivityStatus.ts.html |here} to see how to use GetNetworkConnectivityStatus API.
     */
    getNetworkConnectivityStatus(getNetworkConnectivityStatusRequest: requests.GetNetworkConnectivityStatusRequest): Promise<responses.GetNetworkConnectivityStatusResponse>;
    /**
     * Retrieves the details of operation with given resource name.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetOperationRequest
     * @return GetOperationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetOperation.ts.html |here} to see how to use GetOperation API.
     */
    getOperation(getOperationRequest: requests.GetOperationRequest): Promise<responses.GetOperationResponse>;
    /**
     * Gets a Data Connectivity Management Registry by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetRegistryRequest
     * @return GetRegistryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetRegistry.ts.html |here} to see how to use GetRegistry API.
     */
    getRegistry(getRegistryRequest: requests.GetRegistryRequest): Promise<responses.GetRegistryResponse>;
    /**
     * Retrieves a schema that can be accessed using the specified connection.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSchemaRequest
     * @return GetSchemaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetSchema.ts.html |here} to see how to use GetSchema API.
     */
    getSchema(getSchemaRequest: requests.GetSchemaRequest): Promise<responses.GetSchemaResponse>;
    /**
     * This endpoint retrieves dataAsset and connection attributes from DataAssetRegistry
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetTypeRequest
     * @return GetTypeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetType.ts.html |here} to see how to use GetType API.
     */
    getType(getTypeRequest: requests.GetTypeRequest): Promise<responses.GetTypeResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Retrieves a list of connection validations within the specified registry.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListConnectionValidationsRequest
     * @return ListConnectionValidationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListConnectionValidations.ts.html |here} to see how to use ListConnectionValidations API.
     */
    listConnectionValidations(listConnectionValidationsRequest: requests.ListConnectionValidationsRequest): Promise<responses.ListConnectionValidationsResponse>;
    /**
     * Retrieves a list of all connections.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListConnectionsRequest
     * @return ListConnectionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListConnections.ts.html |here} to see how to use ListConnections API.
     */
    listConnections(listConnectionsRequest: requests.ListConnectionsRequest): Promise<responses.ListConnectionsResponse>;
    /**
     * Retrieves a list of all data asset summaries.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDataAssetsRequest
     * @return ListDataAssetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListDataAssets.ts.html |here} to see how to use ListDataAssets API.
     */
    listDataAssets(listDataAssetsRequest: requests.ListDataAssetsRequest): Promise<responses.ListDataAssetsResponse>;
    /**
     * Lists a summary of data entities from the data asset using the specified connection.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDataEntitiesRequest
     * @return ListDataEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListDataEntities.ts.html |here} to see how to use ListDataEntities API.
     */
    listDataEntities(listDataEntitiesRequest: requests.ListDataEntitiesRequest): Promise<responses.ListDataEntitiesResponse>;
    /**
     * Returns a list of Data Connectivity Management Endpoints.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListEndpointsRequest
     * @return ListEndpointsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListEndpoints.ts.html |here} to see how to use ListEndpoints API.
     */
    listEndpoints(listEndpointsRequest: requests.ListEndpointsRequest): Promise<responses.ListEndpointsResponse>;
    /**
     * Retrieves a list of all folders.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListFoldersRequest
     * @return ListFoldersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListFolders.ts.html |here} to see how to use ListFolders API.
     */
    listFolders(listFoldersRequest: requests.ListFoldersRequest): Promise<responses.ListFoldersResponse>;
    /**
     * Lists the summary of operations present in the schema identified by schema name.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListOperationsRequest
     * @return ListOperationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListOperations.ts.html |here} to see how to use ListOperations API.
     */
    listOperations(listOperationsRequest: requests.ListOperationsRequest): Promise<responses.ListOperationsResponse>;
    /**
     * Retrieves a list of all reference info of a dcms artifact.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListReferenceArtifactsRequest
     * @return ListReferenceArtifactsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListReferenceArtifacts.ts.html |here} to see how to use ListReferenceArtifacts API.
     */
    listReferenceArtifacts(listReferenceArtifactsRequest: requests.ListReferenceArtifactsRequest): Promise<responses.ListReferenceArtifactsResponse>;
    /**
     * Returns a list of Data Connectivity Management Registries.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListRegistriesRequest
     * @return ListRegistriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListRegistries.ts.html |here} to see how to use ListRegistries API.
     */
    listRegistries(listRegistriesRequest: requests.ListRegistriesRequest): Promise<responses.ListRegistriesResponse>;
    /**
     * Retrieves a list of all the schemas that can be accessed using the specified connection.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSchemasRequest
     * @return ListSchemasResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListSchemas.ts.html |here} to see how to use ListSchemas API.
     */
    listSchemas(listSchemasRequest: requests.ListSchemasRequest): Promise<responses.ListSchemasResponse>;
    /**
     * This endpoint retrieves list of all the supported connector types
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTypesRequest
     * @return ListTypesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListTypes.ts.html |here} to see how to use ListTypes API.
     */
    listTypes(listTypesRequest: requests.ListTypesRequest): Promise<responses.ListTypesResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Updates a connection under a data asset.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateConnectionRequest
     * @return UpdateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/UpdateConnection.ts.html |here} to see how to use UpdateConnection API.
     */
    updateConnection(updateConnectionRequest: requests.UpdateConnectionRequest): Promise<responses.UpdateConnectionResponse>;
    /**
     * Updates a specific data asset with default connection.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDataAssetRequest
     * @return UpdateDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/UpdateDataAsset.ts.html |here} to see how to use UpdateDataAsset API.
     */
    updateDataAsset(updateDataAssetRequest: requests.UpdateDataAssetRequest): Promise<responses.UpdateDataAssetResponse>;
    /**
     * Updates the Data Connectivity Management Endpoint
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateEndpointRequest
     * @return UpdateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/UpdateEndpoint.ts.html |here} to see how to use UpdateEndpoint API.
     */
    updateEndpoint(updateEndpointRequest: requests.UpdateEndpointRequest): Promise<responses.UpdateEndpointResponse>;
    /**
     * Updates a folder under a specefied registry.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateFolderRequest
     * @return UpdateFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/UpdateFolder.ts.html |here} to see how to use UpdateFolder API.
     */
    updateFolder(updateFolderRequest: requests.UpdateFolderRequest): Promise<responses.UpdateFolderResponse>;
    /**
     * Updates the Data Connectivity Management Registry
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateRegistryRequest
     * @return UpdateRegistryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/UpdateRegistry.ts.html |here} to see how to use UpdateRegistry API.
     */
    updateRegistry(updateRegistryRequest: requests.UpdateRegistryRequest): Promise<responses.UpdateRegistryResponse>;
    /**
     * Validates the dataAsset network Reachability.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ValidateDataAssetNetworkReachablityRequest
     * @return ValidateDataAssetNetworkReachablityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/ValidateDataAssetNetworkReachablity.ts.html |here} to see how to use ValidateDataAssetNetworkReachablity API.
     */
    validateDataAssetNetworkReachablity(validateDataAssetNetworkReachablityRequest: requests.ValidateDataAssetNetworkReachablityRequest): Promise<responses.ValidateDataAssetNetworkReachablityResponse>;
}
export declare enum NetworkValidationApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class NetworkValidationClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpOptions: any;
    targetService: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * This api is used to get Network Connectivity Status for all the Data Assets attatched to the provided Private endpoint.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetNetworkConnectivityStatusCollectionRequest
     * @return GetNetworkConnectivityStatusCollectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.30.0/dataconnectivity/GetNetworkConnectivityStatusCollection.ts.html |here} to see how to use GetNetworkConnectivityStatusCollection API.
     */
    getNetworkConnectivityStatusCollection(getNetworkConnectivityStatusCollectionRequest: requests.GetNetworkConnectivityStatusCollectionRequest): Promise<responses.GetNetworkConnectivityStatusCollectionResponse>;
}
